@@ -1,5 +1,9 @@
 from yaml2obj.writer import YamlWriter
 from launchable_cli_args.error_counter import ErrorCounter
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from launchable_cli_args.cli_args import Commands
 
 
 class RecordTestsArgs:
@@ -16,7 +20,7 @@ class RecordTestsArgs:
         writer.comment("The test results are placed here in JUnit XML format")
         writer.name("result_dir").value(self.result_dir)
 
-    def to_command(self):
+    def to_command(self) -> "Commands":
         return ("launchable", "record", "tests", "--build", self.parent.eval_build_id(), "pytest", self.result_dir)
 
     @classmethod
